# LANK

## Listening Anchor Nodes for K

In service of:
- **L**abels
- **A**ddresses (peer discovery)
- **N**ames
- **K**eys

## Installation

LANK is easy to install using pip:
```
pip install lank
```

## Usage

Once installed, simply run the `lank` command from any terminal.

